@@ -138,8 +138,8 @@ def fix_trimap(trimap, lower_threshold=0.1, upper_threshold=0.9):
     .. math::
         T^{\\text{fixed}}_{ij}=
         \\begin{cases}
-            0,&\\text{if } T_{ij}<\\text{lower_threshold}\\\\
-            1,&\\text{if }T_{ij}>\\text{upper_threshold}\\\\
+            0,&\\text{if } T_{ij}<\\text{lower\\_threshold}\\\\
+            1,&\\text{if }T_{ij}>\\text{upper\\_threshold}\\\\
             0.5, &\\text{otherwise}.\\\\
         \\end{cases}
 
@@ -148,17 +148,15 @@ def fix_trimap(trimap, lower_threshold=0.1, upper_threshold=0.9):
     ----------
     trimap: numpy.ndarray
         Possibly broken trimap
-
     lower_threshold: float
         Threshold used to determine background pixels, defaults to 0.1
-
     upper_threshold: float
         Threshold used to determine foreground pixels, defaults to 0.9
 
     Returns
     -------
     fixed_trimap: numpy.ndarray
-        Trimap having values in :math:`\{0, 0.5, 1\}`
+        Trimap having values in :math:`\\{0, 0.5, 1\\}`
 
     Example
     -------
@@ -196,7 +194,7 @@ def isiterable(obj):
     Returns
     -------
     is_iterable: bool
-        Boolean variable indicating wether the object is iterable
+        Boolean variable indicating whether the object is iterable
 
     Example
     -------
@@ -441,7 +439,7 @@ def show_images(images):
 def trimap_split(trimap, flatten=True, bg_threshold=0.1, fg_threshold=0.9):
     """This function splits the trimap into foreground pixels, background pixels, and unknown pixels.
 
-    Foreground pixels are pixels where the trimap has values larger than or equal to `fg_threshold` (default: 0.9). 
+    Foreground pixels are pixels where the trimap has values larger than or equal to `fg_threshold` (default: 0.9).
     Background pixels are pixels where the trimap has values smaller than or equal to `bg_threshold` (default: 0.1).
     Pixels with other values are assumed to be unknown.
 
@@ -759,7 +757,7 @@ def grid_coordinates(width, height, flatten=False):
 def sparse_conv_matrix_with_offsets(width, height, kernel, dx, dy):
     """Calculates a convolution matrix that can be applied to a vectorized image
 
-    Additionaly, this function allows to specify which pixels should be used for the convoltion, i.e.
+    Additionally, this function allows to specify which pixels should be used for the convoltion, i.e.
 
     .. math:: \\left(I * K\\right)_{ij} = \\sum_k K_k I_{i+{\\Delta_y}_k,j+{\\Delta_y}_k},
 
@@ -840,7 +838,7 @@ def sparse_conv_matrix(width, height, kernel):
 
 
 def weights_to_laplacian(W, normalize=True, regularization=0.0):
-    """Calculates the random walk normlized Laplacian matrix from the weight matrix
+    """Calculates the random walk normalized Laplacian matrix from the weight matrix
 
     Parameters
     ----------
